#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#
from pathlib import Path

import avro.schema
from avro.datafile import DataFileReader, DataFileWriter
from avro.io import DatumReader, DatumWriter

# read in the schema file
schema_text = Path("user.avsc").read_text()
# then parse it
schema = avro.schema.parse(schema_text)

# create a DataFileWriter to write data to a file
users_file = Path("/tmp/users.avro")
with users_file.open("wb") as users_fh, DataFileWriter(
    users_fh, DatumWriter(), schema
) as writer:
    writer.append({"name": "Alyssa", "favorite_number": 256})
    writer.append({"name": "Ben", "favorite_number": 7, "favorite_color": "red"})

# create a DataFileReader to read data from a file
with users_file.open("rb") as users_fh, DataFileReader(
    users_fh, DatumReader()
) as reader:
    for user in reader:
        print(user)
